==> box64_0.2.6+dfsg.orig.tar.xz: box64-0.2.6/src/wrapped/wrappedicuuc66_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

GO(ubrk_clone_66, pFpp)
GO(ubrk_close_66, vFp)
GO(ubrk_countAvailable_66, iFv)
GO(ubrk_current_66, iFp)
GO(ubrk_first_66, iFp)
GO(ubrk_following_66, iFpi)
GO(ubrk_getAvailable_66, pFi)
GO(ubrk_getBinaryRules_66, iFppip)
GO(ubrk_getLocaleByType_66, pFpip)
GO(ubrk_getRuleStatus_66, iFp)
GO(ubrk_getRuleStatusVec_66, iFppip)
GO(ubrk_isBoundary_66, cFpi)
GO(ubrk_last_66, iFp)
GO(ubrk_next_66, iFp)
GO(ubrk_open_66, pFppip)
GO(ubrk_openBinaryRules_66, pFpipip)
GO(ubrk_openRules_66, pFpipipp)
GO(ubrk_preceding_66, iFpi)
GO(ubrk_previous_66, iFp)
GO(ubrk_refreshUText_66, vFppp)
GO(ubrk_safeClone_66, pFpppp)
GO(ubrk_setText_66, vFppip)
GO(ubrk_setUText_66, vFppp)
GO(ubrk_swap_66, iFppipp)

GO(ucurr_forLocale_66, iFppip)
GO(ucurr_getName_66, pFppippp)

GO(uloc_canonicalize_66, iFppip)
GO(uloc_countAvailable_66, iFv)
GO(uloc_getAvailable_66, pFi)
GO(uloc_getBaseName_66, iFppip)
GO(uloc_getCharacterOrientation_66, iFpp)
GO(uloc_getCountry_66, iFppip)
GO(uloc_getDefault_66, pFv)
GO(uloc_getDisplayCountry_66, iFpppip)
GO(uloc_getDisplayLanguage_66, iFpppip)
GO(uloc_getDisplayName_66, iFpppip)
GO(uloc_getISO3Country_66, pFp)
GO(uloc_getISO3Language_66, pFp)
GO(uloc_getKeywordValue_66, iFpppip)
GO(uloc_getLanguage_66, iFppip)
GO(uloc_getLCID_66, uFp)
GO(uloc_getName_66, iFppip)
GO(uloc_getParent_66, iFppip)
GO(uloc_setKeywordValue_66, iFpppip)

GO(ures_close_66, vFp)
GO(ures_getByKey_66, pFpppp)
GO(ures_getSize_66, iFp)
GO(ures_getStringByIndex_66, pFpipp)
GO(ures_open_66, pFppp)

GO(uldn_close_66, vFp)
GO(uldn_keyValueDisplayName_66, iFppppip)
GO(uldn_open_66, pFpip)

GO(uenum_close_66, vFp)
GO(uenum_count_66, iFpp)
GO(uenum_next_66, pFppp)

GO(uidna_close_66, vFp)
GO(uidna_nameToASCII_66, iFppipipp)
GO(uidna_nameToUnicode_66, iFppipipp)
GO(uidna_openUTS46_66, pFpp)

GO(unorm2_getNFCInstance_66, pFp)
GO(unorm2_getNFDInstance_66, pFp)
GO(unorm2_getNFKCInstance_66, pFp)
GO(unorm2_getNFKDInstance_66, pFp)
GO(unorm2_isNormalized_66, CFppip)
GO(unorm2_normalize_66, iFppipip)

GO(u_charsToUChars_66, vFppi)
GO(u_getVersion_66, vFp)
GO(u_strcmp_66, iFpp)
GO(u_strcpy_66, pFpp)
GO(u_strlen_66, iFp)
GO(u_strncpy_66, pFppi)
GO(u_tolower_66, uFu)
GO(u_toupper_66, uFu)
GO(u_uastrncpy_66, pFppi)

==> box64_0.3.8+dfsg.orig.tar.xz: box64-0.3.8/src/wrapped/wrappedicuuc66_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

GO(ubrk_clone_66, pFpp)
GO(ubrk_close_66, vFp)
GO(ubrk_countAvailable_66, iFv)
GO(ubrk_current_66, iFp)
GO(ubrk_first_66, iFp)
GO(ubrk_following_66, iFpi)
GO(ubrk_getAvailable_66, pFi)
GO(ubrk_getBinaryRules_66, iFppip)
GO(ubrk_getLocaleByType_66, pFpip)
GO(ubrk_getRuleStatus_66, iFp)
GO(ubrk_getRuleStatusVec_66, iFppip)
GO(ubrk_isBoundary_66, cFpi)
GO(ubrk_last_66, iFp)
GO(ubrk_next_66, iFp)
GO(ubrk_open_66, pFppip)
GO(ubrk_openBinaryRules_66, pFpipip)
GO(ubrk_openRules_66, pFpipipp)
GO(ubrk_preceding_66, iFpi)
GO(ubrk_previous_66, iFp)
GO(ubrk_refreshUText_66, vFppp)
GO(ubrk_safeClone_66, pFpppp)
GO(ubrk_setText_66, vFppip)
GO(ubrk_setUText_66, vFppp)
GO(ubrk_swap_66, iFppipp)

GO(ucnv_getDefaultName_66, pFv)
GO(ucnv_open_66, pFpp)
GO(ucnv_setDefaultName_66, vFp)

GO(ucurr_forLocale_66, iFppip)
GO(ucurr_getName_66, pFppippp)

GO(uloc_canonicalize_66, iFppip)
GO(uloc_countAvailable_66, iFv)
GO(uloc_getAvailable_66, pFi)
GO(uloc_getBaseName_66, iFppip)
GO(uloc_getCharacterOrientation_66, iFpp)
GO(uloc_getCountry_66, iFppip)
GO(uloc_getDefault_66, pFv)
GO(uloc_getDisplayCountry_66, iFpppip)
GO(uloc_getDisplayLanguage_66, iFpppip)
GO(uloc_getDisplayName_66, iFpppip)
GO(uloc_getISO3Country_66, pFp)
GO(uloc_getISO3Language_66, pFp)
GO(uloc_getKeywordValue_66, iFpppip)
GO(uloc_getLanguage_66, iFppip)
GO(uloc_getLCID_66, uFp)
GO(uloc_getName_66, iFppip)
GO(uloc_getParent_66, iFppip)
GO(uloc_setKeywordValue_66, iFpppip)

GO(ures_close_66, vFp)
GO(ures_getByKey_66, pFpppp)
GO(ures_getSize_66, iFp)
GO(ures_getStringByIndex_66, pFpipp)
GO(ures_open_66, pFppp)

GO(uldn_close_66, vFp)
GO(uldn_keyValueDisplayName_66, iFppppip)
GO(uldn_open_66, pFpip)

GO(uenum_close_66, vFp)
GO(uenum_count_66, iFpp)
GO(uenum_next_66, pFppp)

GO(uidna_close_66, vFp)
GO(uidna_nameToASCII_66, iFppipipp)
GO(uidna_nameToUnicode_66, iFppipipp)
GO(uidna_openUTS46_66, pFpp)

GO(unorm2_getNFCInstance_66, pFp)
GO(unorm2_getNFDInstance_66, pFp)
GO(unorm2_getNFKCInstance_66, pFp)
GO(unorm2_getNFKDInstance_66, pFp)
GO(unorm2_isNormalized_66, CFppip)
GO(unorm2_normalize_66, iFppipip)

GO(u_charsToUChars_66, vFppi)
GO(u_getVersion_66, vFp)
GO(u_strcmp_66, iFpp)
GO(u_strcpy_66, pFpp)
GO(u_strlen_66, iFp)
GO(u_strncpy_66, pFppi)
GO(u_strToLower_66, iFpipipp)
GO(u_strToUpper_66, iFpipipp)
GO(u_tolower_66, uFu)
GO(u_toupper_66, uFu)
GO(u_uastrncpy_66, pFppi)
